==> zio-aws-elasticache_2.12-5.17.102.7-sources.jar: zio/aws/elasticache/model/CustomerNodeEndpoint.scala <==
package zio.aws.elasticache.model
import java.lang.Integer
import zio.aws.elasticache.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CustomerNodeEndpoint(
    address: Option[String] = None,
    port: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint = {
    import CustomerNodeEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
      .builder()
      .optionallyWith(address.map(value => value: java.lang.String))(_.address)
      .optionallyWith(
        port.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.port)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly =
    zio.aws.elasticache.model.CustomerNodeEndpoint.wrap(buildAwsValue())
}
object CustomerNodeEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.CustomerNodeEndpoint =
      zio.aws.elasticache.model.CustomerNodeEndpoint(
        address.map(value => value),
        port.map(value => value)
      )
    def address: Option[String]
    def port: Option[IntegerOptional]
    def getAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("address", address)
    def getPort: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("port", port)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ) extends zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly {
    override val address: Option[String] =
      scala.Option(impl.address()).map(value => value: String)
    override val port: Option[IntegerOptional] = scala
      .Option(impl.port())
      .map(value => zio.aws.elasticache.model.primitives.IntegerOptional(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ): zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_2.12-5.17.130.5-sources.jar: zio/aws/elasticache/model/CustomerNodeEndpoint.scala <==
package zio.aws.elasticache.model
import java.lang.Integer
import zio.aws.elasticache.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CustomerNodeEndpoint(
    address: Option[String] = None,
    port: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint = {
    import CustomerNodeEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
      .builder()
      .optionallyWith(address.map(value => value: java.lang.String))(_.address)
      .optionallyWith(port.map(value => value: Integer))(_.port)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly =
    zio.aws.elasticache.model.CustomerNodeEndpoint.wrap(buildAwsValue())
}
object CustomerNodeEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.CustomerNodeEndpoint =
      zio.aws.elasticache.model.CustomerNodeEndpoint(
        address.map(value => value),
        port.map(value => value)
      )
    def address: Option[String]
    def port: Option[IntegerOptional]
    def getAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("address", address)
    def getPort: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("port", port)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ) extends zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly {
    override val address: Option[String] =
      scala.Option(impl.address()).map(value => value: String)
    override val port: Option[IntegerOptional] =
      scala.Option(impl.port()).map(value => value: IntegerOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.CustomerNodeEndpoint
  ): zio.aws.elasticache.model.CustomerNodeEndpoint.ReadOnly = new Wrapper(impl)
}
